@@ -29,14 +29,14 @@ from cachetools import TTLCache
 from gs_quant.api.data import DataApi
 from gs_quant.base import Base
 from gs_quant.data.core import DataContext, DataFrequency
+from gs_quant.data.log import log_debug
 from gs_quant.errors import MqValueError
 from gs_quant.markets import MarketDataCoordinate
 from gs_quant.session import GsSession
 from gs_quant.target.common import MarketDataVendor, PricingLocation
 from gs_quant.target.coordinates import MDAPIDataBatchResponse, MDAPIDataQuery, MDAPIDataQueryResponse, MDAPIQueryField
 from gs_quant.target.data import DataQuery, DataQueryResponse
-from gs_quant.target.data import DataSetEntity
-from gs_quant.data.log import log_debug
+from gs_quant.target.data import DataSetEntity, DataSetFieldEntity
 from .assets import GsIdType
 from ...target.assets import EntityQuery, FieldFilterMap
 
@@ -55,6 +55,7 @@ class QueryType(Enum):
     SWAPTION_PREMIUM = "Swaption Premium"
     SWAPTION_ANNUITY = "Swaption Annuity"
     BASIS_SWAP_RATE = "Basis Swap Rate"
+    XCCY_SWAP_SPREAD = "Xccy Swap Spread"
     SWAPTION_VOL = "Swaption Vol"
     MIDCURVE_VOL = "Midcurve Vol"
     CAP_FLOOR_VOL = "Cap Floor Vol"
@@ -106,6 +107,7 @@ class QueryType(Enum):
     INTEGRATED_SCORE = "Integrated Score"
     COMMODITY_FORECAST = "Commodity Forecast"
     FORECAST_VALUE = "Forecast Value"
+    FORWARD_POINT = "Forward Point"
     FCI = "Fci"
     LONG_RATES_CONTRIBUTION = "Long Rates Contribution"
     SHORT_RATES_CONTRIBUTION = "Short Rates Contribution"
@@ -127,6 +129,10 @@ class QueryType(Enum):
     ANNUAL_RISK = "Annual Risk"
     VOLATILITY = "Volatility"
     CORRELATION = "Correlation"
+    OIS_XCCY = "Ois Xccy"
+    OIS_XCCY_EX_SPIKE = "Ois Xccy Ex Spike"
+    USD_OIS = "Usd Ois"
+    NON_USD_OIS = "Non Usd Ois"
 
 
 class GsDataApi(DataApi):
@@ -207,33 +213,30 @@ class GsDataApi(DataApi):
             fields: List[str] = None,
             include_history: bool = False
     ) -> List[dict]:
-        params = {}
-        if scroll:
-            params['scroll'] = scroll
+        params = {
+            'limit': limit or 4000,
+            'scroll': scroll
+        }
 
         if scroll_id:
             params['scrollId'] = scroll_id
-
-        if not limit:
-            limit = 4000
-        params['limit'] = limit
-
         if offset:
             params['offset'] = offset
-
         if fields:
             params['fields'] = fields
-
         if include_history:
             params['includeHistory'] = 'true'
 
-        body = GsSession.current._get('/data/{}/coverage'.format(dataset_id), payload=params)
-        results = body['results']
-        if len(results) > 0 and 'scrollId' in body:
-            return results + cls.get_coverage(dataset_id, scroll_id=body['scrollId'], scroll=GsDataApi.DEFAULT_SCROLL,
-                                              limit=limit)
-        else:
-            return results
+        body = GsSession.current._get(f'/data/{dataset_id}/coverage', payload=params)
+        results = scroll_results = body['results']
+        total_results = body['totalResults']
+        while len(scroll_results) and len(results) < total_results:
+            params['scrollId'] = body['scrollId']
+            body = GsSession.current._get(f'/data/{dataset_id}/coverage', payload=params)
+            scroll_results = body['results']
+            results += scroll_results
+
+        return results
 
     @classmethod
     def create(cls, definition: Union[DataSetEntity, dict]) -> DataSetEntity:
@@ -247,6 +250,10 @@ class GsDataApi(DataApi):
 
     @classmethod
     def upload_data(cls, dataset_id: str, data: Union[pd.DataFrame, list, tuple]) -> dict:
+        if isinstance(data, pd.DataFrame):
+            # We require the Dataframe to return a list in the 'records' format:
+            # https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_json.html
+            data = data.to_json(orient='records')
         result = GsSession.current._post('/data/{}'.format(dataset_id), payload=data)
         return result
 
@@ -672,6 +679,87 @@ class GsDataApi(DataApi):
         else:
             return pd.DataFrame({})
 
+    @classmethod
+    def get_dataset_fields(
+            cls,
+            ids: Union[str, List[str]] = None,
+            names: Union[str, List[str]] = None,
+            limit: int = 10,
+    ) -> Union[Tuple[DataSetFieldEntity, ...], Tuple[dict, ...]]:
+        """
+        Get many dataset fields
+
+        :param ids: ID(s) of the field(s)
+        :param names: Name(s) of the field(s)
+        :param limit: Limit on the number of results returned. Default: 10
+        :return: Tuple of DataSetFieldEntity
+
+        **Examples**
+
+        >>> from gs_quant.api.gs.data import GsDataApi
+        >>> fields = GsDataApi.get_dataset_fields(names = ['adjustedClosePrice', 'adjustedOpenPrice'])
+        """
+
+        where = dict(filter(lambda item: item[1] is not None, dict(id=ids, name=names).items()))
+        response = GsSession.current._post('/data/fields/query',
+                                           payload={'where': where, 'limit': limit},
+                                           cls=DataSetFieldEntity)
+        return response['results']
+
+    @classmethod
+    def create_dataset_fields(
+            cls,
+            fields: List[DataSetFieldEntity]
+    ) -> Union[Tuple[DataSetFieldEntity, ...], Tuple[dict, ...]]:
+        """
+        Create many dataset fields
+
+        :param fields: Fields to be created
+        :return: Tuple of DataSetFieldEntity
+
+        **Examples**
+
+        >>> from gs_quant.api.gs.data import GsDataApi
+        >>> from gs_quant.target.data import DataSetFieldEntity
+        >>> fields = [
+        >>>     DataSetFieldEntity(name='price', type_='number', description='Price of the instrument.'),
+        >>>     DataSetFieldEntity(name='strikeReference', type_='string', description='Reference for strike level.',
+        >>>                        parameters={'enum': ['delta', 'spot', 'forward', 'normalized']})
+        >>> ]
+        >>> GsDataApi.create_dataset_fields(fields)
+        """
+        params = {'fields': fields}
+        response = GsSession.current._post('/data/fields/bulk', payload=params, cls=DataSetFieldEntity)
+        return response['results']
+
+    @classmethod
+    def update_dataset_fields(
+            cls,
+            fields: List[DataSetFieldEntity]
+    ) -> Union[Tuple[DataSetFieldEntity, ...], Tuple[dict, ...]]:
+        """
+        Update many dataset fields
+
+        :param fields: Fields to be created
+        :return: Tuple of DataSetFieldEntity
+
+        **Examples**
+
+        >>> from gs_quant.api.gs.data import GsDataApi
+        >>> from gs_quant.target.data import DataSetFieldEntity
+        >>> fields = [
+        >>>     DataSetFieldEntity(id='FIMFMQ0P19AZ2XK9', name='price', type_='number',
+        >>>                        description='Price of the instrument.'),
+        >>>     DataSetFieldEntity(id='FI7EFDC3SQQBMDX8', name='strikeReference', type_='string',
+        >>>                        description='Reference for strike level.',
+        >>>                        parameters={'enum': ['delta', 'spot', 'forward', 'normalized']})
+        >>> ]
+        >>> GsDataApi.update_dataset_fields(fields)
+        """
+        params = {'fields': fields}
+        response = GsSession.current._put('/data/fields/bulk', payload=params, cls=DataSetFieldEntity)
+        return response['results']
+
 
 class MarketDataResponseFrame(pd.DataFrame):
     _internal_names = pd.DataFrame._internal_names + ['dataset_ids']
