@@ -50,7 +50,7 @@ class GsRiskModelApi:
                         names: List[str] = None,
                         descriptions: List[str] = None,
                         coverages: List[str] = None) -> Tuple[RiskModel, ...]:
-        url = '/risk/models'
+        url = '/risk/models?'
         if limit is not None:
             url += f'&limit={limit}'
         if ids is not None:
@@ -144,7 +144,7 @@ class GsFactorRiskModelApi(GsRiskModelApi):
         if identifiers is not None:
             url += '&identifier={ids}'.format(ids='&identifier='.join(identifiers))
         if include_performance_curve:
-            url += f'&includePerformanceCurve={include_performance_curve}'
+            url += '&includePerformanceCurve=true'
         return GsSession.current._get(url)['results']
 
     @classmethod
