@@ -14,15 +14,12 @@ specific language governing permissions and limitations
 under the License.
 """
 
-from typing import Union, Iterable, Optional
-import datetime
-from enum import Enum
-import pandas as pd
 
-from gs_quant.backtests.actions import Action
+from typing import Optional
+from gs_quant.backtests.actions import Action, AddTradeAction, AddTradeActionInfo
+from gs_quant.backtests.backtest_objects import BackTest, PredefinedAssetBacktest
 from gs_quant.backtests.backtest_utils import make_list, CalcType
-from gs_quant.backtests.backtest_objects import BackTest
-import datetime as dt
+from gs_quant.backtests.data_sources import *
 
 
 class TriggerDirection(Enum):
@@ -77,7 +74,7 @@ class AggregateTriggerRequirements(TriggerRequirements):
 
 
 class DateTriggerRequirements(TriggerRequirements):
-    def __init__(self, dates: Iterable[datetime.date]):
+    def __init__(self, dates: Iterable[dt.date]):
         """
         :param dates: the list of dates on which to trigger
         """
@@ -97,6 +94,36 @@ class PortfolioTriggerRequirements(TriggerRequirements):
         self.direction = direction
 
 
+class MeanReversionTriggerRequirements(TriggerRequirements):
+    def __init__(self, data_source: DataSource,
+                 z_score_bound: float,
+                 rolling_mean_window: int,
+                 rolling_std_window: int):
+        """
+        This trigger will sell when the value hits the z score threshold on the up side, will close out a position
+        when the value crosses the rolling_mean and buy when the value hits the z score threshold on the down side.
+
+        :param data_source: the asset values
+        :param z_score_bound: the threshold level on which to trigger
+        :param rolling_mean_window: the number of values to consider when calculating the rolling mean
+        :param rolling_std_window: the number of values to consider when calculating the standard deviation
+        """
+        super().__init__()
+        self.data_source = data_source
+        self.z_score_bound = z_score_bound
+        self.rolling_mean_window = rolling_mean_window
+        self.rolling_std_window = rolling_std_window
+
+
+class TriggerInfo(object):
+    def __init__(self, triggered: bool, info_dict: Optional[dict] = None):
+        self.triggered = triggered
+        self.info_dict = info_dict
+
+    def __eq__(self, other):
+        return self.triggered is other
+
+
 class Trigger(object):
 
     def __init__(self, trigger_requirements: Optional[TriggerRequirements], actions: Union[Action, Iterable[Action]]):
@@ -105,12 +132,14 @@ class Trigger(object):
         self._risks = [x.risk for x in self.actions if x.risk is not None]
         self._calc_type = CalcType.simple
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         """
         implemented by sub classes
         :param state:
         :param backtest:
         :return:
+            TriggerInfo containing a bool indication of whether the trigger has triggered and optionally info
+            in the form of a dictionary of action type to object info understood by that action.
         """
         raise RuntimeError('has_triggered to be implemented by subclass')
 
@@ -138,7 +167,7 @@ class PeriodicTrigger(Trigger):
         super().__init__(trigger_requirements, actions)
         self._trigger_dates = None
 
-    def get_trigger_dates(self) -> [datetime.date]:
+    def get_trigger_dates(self) -> [dt.date]:
         if not self._trigger_dates:
             self._trigger_dates = pd.date_range(start=self._trigger_requirements.start_date,
                                                 end=self._trigger_requirements.end_date,
@@ -146,10 +175,10 @@ class PeriodicTrigger(Trigger):
             self._trigger_dates = [my_date.date() for my_date in self._trigger_dates]
         return self._trigger_dates
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         if not self._trigger_dates:
             self.get_trigger_dates()
-        return state in self._trigger_dates
+        return TriggerInfo(state in self._trigger_dates)
 
 
 class IntradayPeriodicTrigger(Trigger):
@@ -172,8 +201,8 @@ class IntradayPeriodicTrigger(Trigger):
     def get_trigger_times(self):
         return self._trigger_times
 
-    def has_triggered(self, state: Union[datetime.date, datetime.datetime], backtest: BackTest = None) -> bool:
-        return state.time() in self._trigger_times
+    def has_triggered(self, state: Union[dt.date, dt.datetime], backtest: BackTest = None) -> TriggerInfo:
+        return TriggerInfo(state.time() in self._trigger_times)
 
 
 class MktTrigger(Trigger):
@@ -182,18 +211,18 @@ class MktTrigger(Trigger):
                  actions: Union[Action, Iterable[Action]]):
         super().__init__(trigger_requirements, actions)
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         data_value = self._trigger_requirements.data_source.get_data(state)
         if self._trigger_requirements.direction == TriggerDirection.ABOVE:
             if data_value > self._trigger_requirements.trigger_level:
-                return True
+                return TriggerInfo(True)
         elif self._trigger_requirements.direction == TriggerDirection.BELOW:
             if data_value < self._trigger_requirements.trigger_level:
-                return True
+                return TriggerInfo(True)
         else:
             if data_value == self._trigger_requirements.trigger_level:
-                return True
-        return False
+                return TriggerInfo(True)
+        return TriggerInfo(False)
 
 
 class StrategyRiskTrigger(Trigger):
@@ -204,18 +233,18 @@ class StrategyRiskTrigger(Trigger):
         self._calc_type = CalcType.path_dependent
         self._risks += [trigger_requirements.risk]
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         risk_value = backtest[state][self._trigger_requirements.risk]
         if self._trigger_requirements.direction == TriggerDirection.ABOVE:
             if risk_value > self._trigger_requirements.trigger_level:
-                return True
+                return TriggerInfo(True)
         elif self._trigger_requirements.direction == TriggerDirection.BELOW:
             if risk_value < self._trigger_requirements.trigger_level:
-                return True
+                return TriggerInfo(True)
         else:
             if risk_value == self._trigger_requirements.trigger_level:
-                return True
-        return False
+                return TriggerInfo(True)
+        return TriggerInfo(False)
 
 
 class AggregateTrigger(Trigger):
@@ -226,11 +255,11 @@ class AggregateTrigger(Trigger):
         super().__init__(AggregateTriggerRequirements(triggers), actions)
         self._triggers = triggers
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         for trigger in self._trigger_requirements.triggers:
             if not trigger.has_triggered(state, backtest):
-                return False
-        return True
+                return TriggerInfo(False)
+        return TriggerInfo(True)
 
     @property
     def triggers(self) -> Iterable[Trigger]:
@@ -241,7 +270,7 @@ class DateTrigger(Trigger):
     def __init__(self, trigger_requirements: DateTriggerRequirements, actions: Iterable[Action]):
         super().__init__(trigger_requirements, actions)
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> bool:
         return state in self._trigger_requirements.dates
 
 
@@ -249,17 +278,84 @@ class PortfolioTrigger(Trigger):
     def __init__(self, trigger_requirements: PortfolioTriggerRequirements, actions: Iterable[Action] = None):
         super().__init__(trigger_requirements, actions)
 
-    def has_triggered(self, state: datetime.date, backtest: BackTest = None) -> bool:
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
         if self._trigger_requirements.data_source == 'len':
             value = len(backtest.portfolio_dict)
             if self._trigger_requirements.direction == TriggerDirection.ABOVE:
                 if value > self._trigger_requirements.trigger_level:
-                    return True
+                    return TriggerInfo(True)
             elif self._trigger_requirements.direction == TriggerDirection.BELOW:
                 if value < self._trigger_requirements.trigger_level:
-                    return True
+                    return TriggerInfo(True)
             else:
                 if value == self._trigger_requirements.trigger_level:
-                    return True
+                    return TriggerInfo(True)
 
-        return False
+        return TriggerInfo(False)
+
+
+class MeanReversionTrigger(Trigger):
+    def __init__(self,
+                 trigger_requirements: MeanReversionTriggerRequirements,
+                 actions: Union[Action, Iterable[Action]]):
+        super().__init__(trigger_requirements, actions)
+        self._current_position = 0
+
+    def has_triggered(self, state: dt.date, backtest: BackTest = None) -> TriggerInfo:
+        trigger_req = self._trigger_requirements
+        rolling_mean = trigger_req.data_source.get_data_range(state, trigger_req.rolling_mean_window).mean()
+        rolling_std = trigger_req.data_source.get_data_range(state, trigger_req.rolling_std_window).std()
+        current_price = trigger_req.data_source.get_data(state)
+        if self._current_position == 0:
+            if abs((current_price - rolling_mean) / rolling_std) > self.trigger_requirements.z_score_bound:
+                if current_price > rolling_mean:
+                    self._current_position = -1
+                    return TriggerInfo(True, {AddTradeAction: AddTradeActionInfo(scaling=-1)})
+                else:
+                    self._current_position = 1
+                    return TriggerInfo(True, {AddTradeAction: AddTradeActionInfo(scaling=1)})
+        elif self._current_position == 1:
+            if current_price > rolling_mean:
+                self._current_position = 0
+                return TriggerInfo(True, {AddTradeAction: AddTradeActionInfo(scaling=-1)})
+        elif self._current_position == -1:
+            if current_price > rolling_mean:
+                self._current_position = 0
+                return TriggerInfo(True, {AddTradeAction: AddTradeActionInfo(scaling=1)})
+        else:
+            raise RuntimeWarning(f'unexpected current position: {self._current_position}')
+
+
+class OrdersGeneratorTrigger(Trigger):
+    """Base class for triggers used with the PredefinedAssetEngine."""
+    def __init__(self):
+        super().__init__(None, Action())
+
+    def get_trigger_times(self) -> list:
+        """
+        Returns the set of times when orders can be generated e.g. every 30 min
+        :return: list
+        """
+        raise RuntimeError('get_trigger_times must be implemented by subclass')
+
+    def generate_orders(self, state: dt.datetime, backtest: PredefinedAssetBacktest = None) -> list:
+        """
+        Returns the orders generated at state
+        :param state: the time when orders are generated
+        :param backtest: the backtest, used to access the holdings and orders generated so far
+        :return: list
+        """
+        raise RuntimeError('generate_orders must be implemented by subclass')
+
+    def has_triggered(self, state: dt.datetime, backtest: PredefinedAssetBacktest = None) -> TriggerInfo:
+        """
+        Calls generate_orders if state is among the trigger times
+        :param state: the time of the trigger
+        :param backtest: the backtest, used to access the holdings and orders generated so far
+        :return: list
+        """
+        if state.time() not in self.get_trigger_times():
+            return TriggerInfo(False)
+        else:
+            orders = self.generate_orders(state, backtest)
+            return TriggerInfo(True, {type(a): orders for a in self.actions}) if len(orders) else TriggerInfo(False)
