@@ -31,12 +31,11 @@ class PositionType(Enum):
 
     OPEN = "open"  #: Open positions (corporate action adjusted)
     CLOSE = "close"  #: Close positions (reflect trading activity on the close)
+    ANY = 'any'
 
 
 class DateLimit(Enum):
     
-    """ Low limit and high limit date objects """
+    """ Datetime date constants """
 
     LOW_LIMIT = dt.date(1952, 1, 1)
-    TODAY = dt.date.today()
-    HIGH_LIMIT = dt.date.today() + dt.timedelta(days=10)
