@@ -14,32 +14,26 @@ specific language governing permissions and limitations
 under the License.
 """
 from math import sqrt
-from typing import Dict
+from typing import Dict, Union
+
+import pandas as pd
 
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.data.core import DataContext
 from gs_quant.datetime import date
-from gs_quant.models.risk_model import FactorRiskModel, ReturnFormat
 from gs_quant.errors import MqValueError
+from gs_quant.models.risk_model import FactorRiskModel, ReturnFormat
 from gs_quant.target.data import DataQuery
 
 
 class Factor:
 
-    def __init__(self, risk_model_id: str, factor_name: str):
-        risk_model = FactorRiskModel(risk_model_id)
-        factor_data = risk_model.get_factor_data(format=ReturnFormat.JSON)
-        name_matches = [factor for factor in factor_data if factor['name'] == factor_name]
-
-        if not name_matches:
-            raise MqValueError(f'Factor with name {factor_name} does not in exist in risk model {risk_model_id}')
-
-        factor = name_matches.pop()
-        self.__risk_model_id: str = risk_model_id
-        self.__id = factor['identifier']
-        self.__name: str = factor['name']
-        self.__type: str = factor['type']
-        self.__category: str = factor.get('factorCategory')
+    def __init__(self, risk_model_id: str, id_: str, name: str, type: str, category: str):
+        self.__risk_model_id = risk_model_id
+        self.__id = id_
+        self.__name = name
+        self.__type = type
+        self.__category = category
 
     @property
     def id(self):
@@ -61,11 +55,25 @@ class Factor:
     def risk_model_id(self):
         return self.__risk_model_id
 
+    @classmethod
+    def get(cls, risk_model_id: str, factor_name: str):
+        risk_model = FactorRiskModel.get(risk_model_id)
+        factor_data = risk_model.get_factor_data(format=ReturnFormat.JSON)
+        name_matches = [factor for factor in factor_data if factor['name'] == factor_name]
+
+        if not name_matches:
+            raise MqValueError(f'Factor with name {factor_name} does not in exist in risk model {risk_model_id}')
+
+        factor = name_matches.pop()
+        return Factor(risk_model_id, factor['identifier'], factor['name'], factor['type'], factor.get('factorCategory'))
+
     def covariance(self,
                    factor,
                    start_date: date = DataContext.current.start_date,
-                   end_date: date = DataContext.current.end_date) -> Dict:
-        """ Retrieve a Dictionary of date->covariance values between this factor and another for a date range """
+                   end_date: date = DataContext.current.end_date,
+                   format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """ Retrieve a Dataframe or Dictionary of date->covariance values between this factor and another for a date
+        range """
 
         covariance_data_raw = GsDataApi.execute_query(
             'RISK_MODEL_COVARIANCE_MATRIX',
@@ -85,39 +93,55 @@ class Factor:
                 matrix_order_on_date = date_to_matrix_order[date]
                 covariance_data[date] = data[matrix_order_on_date]
 
+        if format == ReturnFormat.DATA_FRAME:
+            return pd.DataFrame.from_dict(covariance_data, orient='index', columns=['covariance'])
         return covariance_data
 
     def variance(self,
                  start_date: date = DataContext.current.start_date,
-                 end_date: date = DataContext.current.end_date) -> Dict:
-        """ Retrieve a Dictionary of date->variance values for a factor over a date range """
-        return self.covariance(self, start_date, end_date)
+                 end_date: date = DataContext.current.end_date,
+                 format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """ Retrieve a Dataframe or Dictionary of date->variance values for a factor over a date range """
+        variance_data = self.covariance(self, start_date, end_date, ReturnFormat.JSON)
+
+        if format == ReturnFormat.DATA_FRAME:
+            return pd.DataFrame.from_dict(variance_data, orient='index', columns=['variance'])
+        return variance_data
 
     def volatility(self,
                    start_date: date = DataContext.current.start_date,
-                   end_date: date = DataContext.current.end_date) -> Dict:
-        """ Retrieve a Dictionary of date->volatility values for a factor over a date range """
-        variance = self.variance(start_date, end_date)
-        return {k: sqrt(v) for k, v in variance.items()}
+                   end_date: date = DataContext.current.end_date,
+                   format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """ Retrieve a Dataframe or Dictionary of date->volatility values for a factor over a date range """
+        variance = self.variance(start_date, end_date, ReturnFormat.JSON)
+        volatility_data = {k: sqrt(v) for k, v in variance.items()}
+
+        if format == ReturnFormat.DATA_FRAME:
+            return pd.DataFrame.from_dict(volatility_data, orient='index', columns=['volatility'])
+        return volatility_data
 
     def correlation(self,
                     other_factor,
                     start_date: date = DataContext.current.start_date,
-                    end_date: date = DataContext.current.end_date) -> Dict:
-        """ Retrieve a Dictionary of date->correlation values between this factor and another for a date range """
+                    end_date: date = DataContext.current.end_date,
+                    format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
+        """ Retrieve a Dataframe or Dictionary of date->correlation values between this factor and another for a date
+        range """
 
-        factor_vol = self.volatility(start_date, end_date)
-        other_factor_vol = other_factor.volatility(start_date, end_date)
-        covariance = self.covariance(other_factor, start_date, end_date)
+        factor_vol = self.volatility(start_date, end_date, ReturnFormat.JSON)
+        other_factor_vol = other_factor.volatility(start_date, end_date, ReturnFormat.JSON)
+        covariance = self.covariance(other_factor, start_date, end_date, ReturnFormat.JSON)
 
-        correlation = {}
+        correlation_data = {}
         for _date, covar in covariance.items():
             if _date in factor_vol and _date in other_factor_vol:
                 denominator = factor_vol[_date] * other_factor_vol[_date]
                 if denominator != 0:
-                    correlation[_date] = covar / denominator
+                    correlation_data[_date] = covar / denominator
 
-        return correlation
+        if format == ReturnFormat.DATA_FRAME:
+            return pd.DataFrame.from_dict(correlation_data, orient='index', columns=['correlation'])
+        return correlation_data
 
     def __matrix_order(self, start_date: date, end_date: date) -> Dict:
         """ Retrieve Dictionary of date->matrix_order for the factor in the covariance matrix """
