@@ -19,7 +19,7 @@ import json
 import threading
 from abc import ABCMeta, abstractmethod
 from enum import Enum
-from typing import Optional, Tuple, Union, Dict
+from typing import Dict, Optional, Tuple, Union
 
 import cachetools
 import pandas as pd
@@ -131,6 +131,12 @@ class AssetType(Enum):
     #: Crypto
     CRYPTOCURRENCY = "Cryptocurrency"
 
+    #: Forward
+    FORWARD = "Forward"
+
+    #: Fund
+    FUND = "Fund"
+
 
 class AssetIdentifier(EntityIdentifier):
     """Asset type enumeration
@@ -419,8 +425,11 @@ class Cross(Asset):
     def __init__(self,
                  id_: str,
                  name: str,
-                 entity: Optional[Dict] = None):
-        Asset.__init__(self, id_, AssetClass.FX, name, entity=entity)
+                 entity: Optional[Dict] = None,
+                 asset_class: Optional[Union[AssetClass, str]] = AssetClass.FX):
+        if isinstance(asset_class, str):
+            asset_class = get_enum_value(AssetClass, asset_class)
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
 
     def get_type(self) -> AssetType:
         return AssetType.CROSS
@@ -662,6 +671,22 @@ class Bond(Asset):
         return AssetType.BOND
 
 
+class Fund(Asset):
+    """Fund
+    Represents a fund.
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 asset_class: AssetClass,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.FUND
+
+
 class FutureMarket(Asset):
     """Future Market
 
@@ -744,6 +769,22 @@ class Option(Asset):
         return AssetType.OPTION
 
 
+class Forward(Asset):
+
+    def __init__(self,
+                 id_: str,
+                 asset_class: Union[AssetClass, str],
+                 name: str,
+                 entity: Optional[Dict] = None):
+        if isinstance(asset_class, str):
+            asset_class = get_enum_value(AssetClass, asset_class)
+
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.FORWARD
+
+
 class Index(Asset, PositionedEntity):
     """Index Asset
 
@@ -841,7 +882,7 @@ class SecurityMaster:
             return Future(gs_asset.id, gs_asset.assetClass, gs_asset.name, gs_asset.currency, entity=asset_entity)
 
         if asset_type in (GsAssetType.Cross.value,):
-            return Cross(gs_asset.id, gs_asset.name, entity=asset_entity)
+            return Cross(gs_asset.id, gs_asset.name, entity=asset_entity, asset_class=gs_asset.assetClass)
 
         if asset_type in (GsAssetType.Currency.value,):
             return Currency(gs_asset.id, gs_asset.name, entity=asset_entity)
@@ -892,6 +933,12 @@ class SecurityMaster:
         if asset_type == GsAssetType.Cryptocurrency.value:
             return Cryptocurrency(gs_asset.id, gs_asset.assetClass, gs_asset.name, entity=asset_entity)
 
+        if asset_type == GsAssetType.Forward.value:
+            return Forward(gs_asset.id, gs_asset.assetClass, gs_asset.name, entity=asset_entity)
+
+        if asset_type == GsAssetType.Fund.value:
+            return Fund(gs_asset.id, gs_asset.name, gs_asset.assetClass, entity=asset_entity)
+
         raise TypeError(f'unsupported asset type {asset_type}')
 
     @classmethod
@@ -916,8 +963,7 @@ class SecurityMaster:
                   as_of: Union[dt.date, dt.datetime] = None,
                   exchange_code: ExchangeCode = None,
                   asset_type: AssetType = None,
-                  sort_by_rank: bool = False
-                  ) -> Asset:
+                  sort_by_rank: bool = False) -> Asset:
         """
         Get an asset by identifier and identifier type
 
