@@ -16,17 +16,13 @@ under the License.
 import datetime as dt
 from enum import auto
 from typing import List, Dict, Union
-
 import pandas as pd
 
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.api.gs.risk_models import GsFactorRiskModelApi, GsRiskModelApi
-from gs_quant.data.dataset import Dataset
-from gs_quant.errors import MqValueError
 from gs_quant.models.factor_risk_model_utils import build_asset_data_map, build_factor_data_map, \
     build_factor_data_dataframe, build_pfp_data_dataframe, get_isc_dataframe, get_covariance_matrix_dataframe, \
-    get_closest_date_index, divide_request, to_datetime, get_most_recent_date_from_calendar, \
-    batch_and_upload_partial_data
+    get_closest_date_index, divide_request, batch_and_upload_partial_data
 from gs_quant.target.common import Enum
 from gs_quant.target.risk_models import RiskModel as RiskModelBuilder
 from gs_quant.target.risk_models import RiskModelData, RiskModelCalendar, RiskModelFactor, \
@@ -40,124 +36,68 @@ class ReturnFormat(Enum):
 
 
 class RiskModel:
-    def __init__(self, model_id: str):
-        model = GsRiskModelApi.get_risk_model(model_id)
-        self.__id: str = model.id
-        self.__name: str = model.name
-        self.__description: str = model.description
-        self.__entitlements: Entitlements = model.entitlements if type(model.entitlements) == Entitlements or not\
-            model.entitlements else Entitlements.from_dict(model.entitlements)
+    """ Risk Model Class """
+
+    def __init__(self,
+                 model_id: str,
+                 name: str,
+                 entitlements: Union[Dict, Entitlements] = None,
+                 description: str = None):
+        self.__id: str = model_id
+        self.__name: str = name
+        self.__description: str = description
+        self.__entitlements: Entitlements = entitlements if entitlements and isinstance(entitlements, Entitlements) \
+            else Entitlements.from_dict(entitlements) if entitlements and isinstance(entitlements, Dict) else None
 
     @property
     def id(self) -> str:
-        """ Retrieve risk model id for existing risk model """
+        """ Get risk model id """
         return self.__id
 
     @property
     def name(self) -> str:
-        """ Retrieve risk model name for existing risk model """
+        """ Get risk model name """
         return self.__name
 
     @name.setter
     def name(self, name: str):
-        """ Set risk model name for existing risk model """
+        """ Set risk model name """
         self.__name = name
 
     @property
     def description(self) -> str:
-        """ Retrieve risk model description for existing risk model """
+        """ Get risk model description """
         return self.__description
 
     @description.setter
     def description(self, description: str):
-        """ Sets description for existing risk model """
+        """ Set risk model description """
         self.__description = description
 
     @property
     def entitlements(self) -> Entitlements:
+        """ Get risk model entitlements """
         return self.__entitlements
 
     @entitlements.setter
     def entitlements(self, entitlements: Union[Entitlements, Dict]):
+        """ Set risk model entitlements """
         self.__entitlements = entitlements
 
-    def add_entitlements(self, entitlements: Union[Entitlements, Dict]):
-        entitlements = Entitlements.from_dict(entitlements) if type(entitlements) == dict else entitlements
-        edit = self.__entitlements.edit
-        for user in entitlements.edit:
-            if user not in edit:
-                edit += user,
-        admin = self.__entitlements.admin
-        for user in entitlements.admin:
-            if user not in edit:
-                admin += user,
-        query = self.__entitlements.query
-        for user in entitlements.query:
-            if user not in query:
-                query += user,
-        upload = self.__entitlements.upload
-        for user in entitlements.upload:
-            if user not in upload:
-                upload += user,
-        view = self.__entitlements.view
-        for user in entitlements.view:
-            if user not in view:
-                view += user,
-        execute = self.__entitlements.execute
-        for user in entitlements.execute:
-            if user not in execute:
-                execute += user,
-        combined_entitlements = Entitlements(
-            edit=edit,
-            admin=admin,
-            query=query,
-            upload=upload,
-            view=view,
-            execute=execute
-        )
-        self.entitlements = combined_entitlements
-
-    def remove_entitlements(self, entitlements: Union[Entitlements, Dict]):
-        entitlements = Entitlements.from_dict(entitlements) if type(entitlements) == dict else entitlements
-        model = GsRiskModelApi.get_risk_model(self.__id)
-        edit_ls = list(model.entitlements.edit)
-        for edit in entitlements.edit:
-            edit_ls.remove(edit)
-        admin_ls = list(model.entitlements.admin)
-        for admin in entitlements.admin:
-            admin_ls.remove(admin)
-        query_ls = list(model.entitlements.query)
-        for query in entitlements.query:
-            query_ls.remove(query)
-        upload_ls = list(model.entitlements.upload)
-        for upload in entitlements.upload:
-            upload_ls.remove(upload)
-        view_ls = list(model.entitlements.view)
-        for view in entitlements.view:
-            view_ls.remove(view)
-        execute_ls = list(model.entitlements.execute)
-        for execute in entitlements.execute:
-            execute_ls.remove(execute)
-        removed_entitlements = Entitlements(
-            edit=tuple(edit_ls),
-            admin=tuple(admin_ls),
-            query=tuple(query_ls),
-            upload=tuple(upload_ls),
-            view=tuple(view_ls),
-            execute=tuple(execute_ls)
-        )
-        self.entitlements = removed_entitlements
-
     def delete(self):
-        """ Delete existing risk model """
+        """ Delete existing risk model object from Marquee """
         return GsRiskModelApi.delete_risk_model(self.id)
 
     def get_dates(self, start_date: dt.date = None, end_date: dt.date = None) -> List:
-        """ Retrieve risk model dates for existing risk model """
+        """ Get risk model dates for existing risk model
+            :param start_date: list returned including and after start_date
+            :param end_date: list returned up to and including end_date """
         return GsRiskModelApi.get_risk_model_dates(self.id, start_date, end_date)
 
     def get_calendar(self, start_date: dt.date = None, end_date: dt.date = None) -> RiskModelCalendar:
-        """ Retrieve risk model calendar for existing risk model between start and end date """
+        """ Get risk model calendar for existing risk model between start and end date
+            :param start_date: list returned including and after start_date
+            :param end_date: list returned up to and including end_date """
         calendar = GsRiskModelApi.get_risk_model_calendar(self.id)
         if not start_date and not end_date:
             return calendar
@@ -167,129 +107,167 @@ class RiskModel:
         return RiskModelCalendar(calendar.business_dates[start_idx:end_idx + 1])
 
     def upload_calendar(self, calendar: RiskModelCalendar):
-        """ Upload risk model calendar to existing risk model """
+        """ Upload risk model calendar to existing risk model
+            :param calendar: RiskModelCalendar containing list of dates where model data is expected"""
         return GsRiskModelApi.upload_risk_model_calendar(self.id, calendar)
 
     def get_missing_dates(self, end_date: dt.date = None):
-        """Takes in a risk model id and returns any dates where data is not published according to expected days
-        returned from the risk model calendar until specified end_date. If no end_date is provided, end_date defaults
-        to the most recent business date according to the risk model calendar"""
-        posted_results = GsFactorRiskModelApi.get_risk_model_dates(self.id)
+        """ Get any dates where data is not published according to expected days returned from the risk model calendar
+            :param end_date: date to truncate missing dates at
+
+            If no end_date is provided, end_date defaults to T-1 date according
+                to the risk model calendar """
+        posted_results = self.get_dates()
         if not end_date:
             end_date = dt.date.today() - dt.timedelta(days=1)
         calendar = self.get_calendar(
-            start_date=to_datetime(posted_results[0]),
+            start_date=dt.datetime.strptime((posted_results[0]), '%Y-%m-%d').date(),
             end_date=end_date).business_dates
         return [date for date in calendar if date not in posted_results]
 
     def get_most_recent_date_from_calendar(self) -> dt.date:
-        """Returns most recent date in calendar from and including yesterday"""
-        return get_most_recent_date_from_calendar(self.id)
+        """ Get T-1 date according to risk model calendar """
+        yesterday = dt.date.today() - dt.timedelta(1)
+        calendar = self.get_calendar(end_date=yesterday).business_dates
+        return dt.datetime.strptime(calendar[len(calendar) - 1], '%Y-%m-%d').date()
 
 
 class FactorRiskModel(RiskModel):
-    def __init__(self, model_id: str):
-        super().__init__(model_id)
-        model = GsRiskModelApi.get_risk_model(model_id)
-        self.__coverage: Union[CoverageType, str] = model.coverage
-        self.__term: Union[Term, str] = model.term
-        self.__universe_identifier: Union[UniverseIdentifier, str] = model.universe_identifier
-        self.__vendor: str = model.vendor
-        self.__version: float = model.version
+    """ Factor Risk Model used for calculating asset level factor risk"""
+
+    def __init__(self,
+                 model_id: str,
+                 name: str,
+                 coverage: Union[CoverageType, str],
+                 term: Union[Term, str],
+                 universe_identifier: Union[UniverseIdentifier, str],
+                 vendor: str,
+                 version: float,
+                 entitlements: Union[Dict, Entitlements] = None,
+                 description: str = None):
+        """ Create new factor risk model object
+                   :param model_id: risk model id (cannot be changed)
+                   :param name: risk model name
+                   :param coverage: coverage of risk model asset universe
+                   :param term: horizon term
+                   :param universe_identifier: identifier used in asset universe upload (cannot be changed)
+                   :param vendor: risk model vendor
+                   :param version: version of model
+                   :param entitlements: entitlements associated with risk model
+                   :param description: risk model description
+                   :return: Factor Risk Model object  """
+        super().__init__(model_id, name, entitlements=entitlements, description=description)
+        self.__coverage = coverage if isinstance(coverage, CoverageType) else CoverageType(coverage)
+        self.__term = term if isinstance(term, Term) else Term(term)
+        self.__universe_identifier = universe_identifier if universe_identifier and \
+            isinstance(universe_identifier, UniverseIdentifier) else UniverseIdentifier(universe_identifier) if\
+            universe_identifier else None
+        self.__vendor = vendor
+        self.__version = version
 
     @property
     def vendor(self) -> str:
-        """ Retrieve risk model vendor for existing risk model """
+        """ Get risk model vendor """
         return self.__vendor
 
     @vendor.setter
     def vendor(self, vendor):
-        """ Sets risk model vendor for existing risk model """
+        """ Set risk model vendor """
         self.__vendor = vendor
 
     @property
     def universe_identifier(self) -> str:
-        """ Retrieve risk model universe identifier for existing risk model """
+        """ Get risk model universe identifier """
         return self.__universe_identifier
 
     @property
     def term(self) -> str:
-        """ Retrieve risk model term for existing risk model """
+        """ Get risk model term """
         return self.__term
 
     @term.setter
     def term(self, term: Union[Term, str]):
-        """ Set term for existing risk model """
+        """ Set risk model term """
         self.__term = term
 
     @property
     def version(self) -> float:
-        """ Retrieve risk model version for existing risk model """
+        """ Get risk model version """
         return self.__version
 
     @version.setter
     def version(self, version: float):
-        """ Set version for existing risk model """
+        """ Set risk model version """
         self.__version = version
 
     @property
     def coverage(self) -> str:
-        """ Retrieve risk model coverage for existing risk model """
+        """ Get risk model coverage """
         return self.__coverage
 
     @coverage.setter
     def coverage(self, coverage: Union[CoverageType, str]):
-        """ Sets risk model coverage for existing risk model """
+        """ Set risk model coverage """
         self.__coverage = coverage
 
     @classmethod
-    def create(cls,
-               coverage: Union[CoverageType, str],
-               id_: str,
-               name: str,
-               term: Union[Term, str],
-               universe_identifier: Union[UniverseIdentifier, str],
-               vendor: str,
-               version: float,
-               entitlements: Union[Entitlements, Dict] = None):
-        new_model = RiskModelBuilder(coverage, id_, name, term, universe_identifier, vendor, version,
-                                     entitlements=entitlements)
-        GsRiskModelApi.create_risk_model(new_model)
-        return FactorRiskModel(id_)
+    def get(cls, model_id: str):
+        """ Get a factor risk model from Marquee
+            :param model_id: risk model id corresponding to Marquee Factor Risk Model
+            :return: Factor Risk Model object  """
+        model = GsRiskModelApi.get_risk_model(model_id)
+        return FactorRiskModel(model_id,
+                               model.name,
+                               model.coverage,
+                               model.term,
+                               model.universe_identifier,
+                               model.vendor,
+                               model.version,
+                               entitlements=model.entitlements,
+                               description=model.description)
 
-    def update(self,
-               coverage: Union[CoverageType, str] = None,
-               name: str = None,
-               term: Union[Term, str] = None,
-               version: float = None,
-               vendor: str = None,
-               description: str = None,
-               entitlements: Union[Entitlements, Dict] = None):
-        coverage = coverage or self.coverage
-        name = name or self.name
-        term = term or self.term
-        description = description or self.description
-        entitlements = entitlements or self.entitlements
-        version = version or self.version
-        vendor = vendor or self.vendor
-        updated_model = RiskModelBuilder(coverage, self.id, name, term, self.universe_identifier,
-                                         vendor, version, description=description, entitlements=entitlements)
+    def upload(self):
+        """ Upload current Factor Risk Model object to Marquee """
+        new_model = RiskModelBuilder(self.coverage,
+                                     self.id,
+                                     self.name,
+                                     self.term,
+                                     self.universe_identifier,
+                                     self.vendor,
+                                     self.version,
+                                     entitlements=self.entitlements,
+                                     description=self.description)
+        GsRiskModelApi.create_risk_model(new_model)
+
+    def update(self):
+        """ Update factor risk model object on Marquee """
+        updated_model = RiskModelBuilder(self.coverage, self.id, self.name, self.term, self.universe_identifier,
+                                         self.vendor, self.version, description=self.description,
+                                         entitlements=self.entitlements)
         GsRiskModelApi.update_risk_model(updated_model)
 
     def get_factor(self, factor_id: str) -> RiskModelFactor:
-        """ Retrieve risk model factor from model and factor ids """
+        """ Get risk model factor from model and factor ids
+            :param factor_id: factor identifier associated with risk model
+            :return: Risk Model Factor object """
         return GsFactorRiskModelApi.get_risk_model_factor(self.id, factor_id)
 
-    def create_factor(self, factor: RiskModelFactor):
-        """ Create a new risk model factor """
-        GsFactorRiskModelApi.create_risk_model_factor(self.id, factor)
+    def create_factor(self, factor: RiskModelFactor) -> RiskModelFactor:
+        """ Create a new risk model factor
+            :param factor: factor object
+            :return: Risk Model Factor object """
+        return GsFactorRiskModelApi.create_risk_model_factor(self.id, factor)
 
-    def update_factor(self, factor_id: str, factor: RiskModelFactor):
-        """ Update existing risk model factor """
-        GsFactorRiskModelApi.update_risk_model_factor(self.id, factor_id, factor)
+    def update_factor(self, factor_id: str, factor: RiskModelFactor) -> RiskModelFactor:
+        """ Update existing risk model factor
+            :param factor_id: factor identifier associated with risk model to update
+            :param factor: factor object associated with risk model
+            :return: Risk Model Factor object """
+        return GsFactorRiskModelApi.update_risk_model_factor(self.id, factor_id, factor)
 
     def delete_factor(self, factor_id: str):
-        """ Delete a risk model factor """
+        """ Delete a risk model factor
+            :param factor_id: factor identifier associated with risk model to delete """
         GsFactorRiskModelApi.delete_risk_model_factor(self.id, factor_id)
 
     def get_factor_data(self,
@@ -298,7 +276,13 @@ class FactorRiskModel(RiskModel):
                         identifiers: List[str] = None,
                         include_performance_curve: bool = False,
                         format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve factor data for existing risk model """
+        """ Get factor data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param identifiers: list of factor ids associated with risk model
+            :param include_performance_curve: request to include the performance curve of the factors
+            :param format: which format to return the results in
+            :return: risk model factor data """
         factor_data = GsFactorRiskModelApi.get_risk_model_factor_data(
             self.id,
             start_date,
@@ -313,9 +297,15 @@ class FactorRiskModel(RiskModel):
     def get_asset_universe(self,
                            start_date: dt.date,
                            end_date: dt.date = None,
-                           assets: DataAssetsRequest = None,
+                           assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                            format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve asset universe data for existing risk model """
+        """ Get asset universe data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: risk model universe """
+
         if not assets.universe and not end_date:
             end_date = start_date
         results = GsFactorRiskModelApi.get_risk_model_data(
@@ -326,7 +316,7 @@ class FactorRiskModel(RiskModel):
             measures=[Measure.Asset_Universe],
             limit_factors=False
         ).get('results')
-        dates = [to_datetime(data.get('date')) for data in results]
+        dates = [dt.datetime.strptime((data.get('date')), '%Y-%m-%d').date() for data in results]
         universe = [data.get('assetData').get('universe') for data in results]
         dates_to_universe = dict(zip(dates, universe))
         if format == ReturnFormat.DATA_FRAME:
@@ -336,9 +326,14 @@ class FactorRiskModel(RiskModel):
     def get_historical_beta(self,
                             start_date: dt.date,
                             end_date: dt.date = None,
-                            assets: DataAssetsRequest = None,
+                            assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                             format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve historical beta data for existing risk model """
+        """ Get historical beta data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: historical beta for assets requested """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -356,9 +351,14 @@ class FactorRiskModel(RiskModel):
     def get_total_risk(self,
                        start_date: dt.date,
                        end_date: dt.date = None,
-                       assets: DataAssetsRequest = None,
+                       assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                        format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve total risk data for existing risk model """
+        """ Get total risk data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: total risk for assets requested """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -376,9 +376,14 @@ class FactorRiskModel(RiskModel):
     def get_specific_risk(self,
                           start_date: dt.date,
                           end_date: dt.date = None,
-                          assets: DataAssetsRequest = None,
+                          assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                           format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve specific risk data for existing risk model """
+        """ Get specific risk data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: specific risk for assets requested """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -396,13 +401,14 @@ class FactorRiskModel(RiskModel):
     def get_residual_variance(self,
                               start_date: dt.date,
                               end_date: dt.date = None,
-                              assets: DataAssetsRequest = None,
+                              assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                               format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve residual variance data for existing risk model """
-        if not assets:
-            assets = DataAssetsRequest(UniverseIdentifier.gsid, [])
-        if assets.identifier != UniverseIdentifier.gsid:
-            raise MqValueError('Cannot query residual variance by identifiers other than gsid')
+        """ Get residual variance data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: residual variance for assets requested """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -420,9 +426,14 @@ class FactorRiskModel(RiskModel):
     def get_universe_factor_exposure(self,
                                      start_date: dt.date,
                                      end_date: dt.date = None,
-                                     assets: DataAssetsRequest = None,
+                                     assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                                      format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[List[Dict], pd.DataFrame]:
-        """ Retrieve universe factor exposure data for existing risk model """
+        """ Get universe factor exposure data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: factor exposure for assets requested """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -446,7 +457,11 @@ class FactorRiskModel(RiskModel):
                                    start_date: dt.date,
                                    end_date: dt.date = None,
                                    format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
-        """ Retrieve factor return data for existing risk model """
+        """ Get factor return data for existing risk model keyed by name
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param format: which format to return the results in
+            :return: factor returns by name """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -463,7 +478,11 @@ class FactorRiskModel(RiskModel):
                                  start_date: dt.date,
                                  end_date: dt.date = None,
                                  format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
-        """ Retrieve factor return data for existing risk model """
+        """ Get factor return data for existing risk model keyed by factor id
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param format: which format to return the results in
+            :return: factor returns by factor id """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -480,7 +499,11 @@ class FactorRiskModel(RiskModel):
                               start_date: dt.date,
                               end_date: dt.date = None,
                               format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
-        """ Retrieve covariance matrix data for existing risk model """
+        """ Get covariance matrix data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param format: which format to return the results in
+            :return: covariance matrix of daily factor returns """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -495,9 +518,14 @@ class FactorRiskModel(RiskModel):
     def get_issuer_specific_covariance(self,
                                        start_date: dt.date,
                                        end_date: dt.date = None,
-                                       assets: DataAssetsRequest = None,
+                                       assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                                        format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
-        """ Retrieve issuer specific covariance data for existing risk model """
+        """ Get issuer specific covariance data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: issuer specific covariance matrix (covariance of assets with the same issuer) """
         isc = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -506,15 +534,20 @@ class FactorRiskModel(RiskModel):
             measures=[Measure.Issuer_Specific_Covariance],
             limit_factors=False
         ).get('results')
-        isc_data = isc if format == ReturnFormat.DATA_FRAME else get_isc_dataframe(isc)
+        isc_data = isc if format == ReturnFormat.JSON else get_isc_dataframe(isc)
         return isc_data
 
     def get_factor_portfolios(self,
                               start_date: dt.date,
                               end_date: dt.date = None,
-                              assets: DataAssetsRequest = None,
+                              assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
                               format: ReturnFormat = ReturnFormat.DATA_FRAME) -> Union[Dict, pd.DataFrame]:
-        """ Retrieve factor portfolios data for existing risk model """
+        """ Get factor portfolios data for existing risk model
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param format: which format to return the results in
+            :return: factor portfolios data """
         results = GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -530,9 +563,16 @@ class FactorRiskModel(RiskModel):
                  measures: List[Measure],
                  start_date: dt.date,
                  end_date: dt.date = None,
-                 assets: DataAssetsRequest = None,
-                 limit_factors: bool = None) -> Dict:
-        """ Retrieve data for multiple measures for existing risk model """
+                 assets: DataAssetsRequest = DataAssetsRequest(UniverseIdentifier.gsid, []),
+                 limit_factors: bool = True) -> Dict:
+        """ Get data for multiple measures for existing risk model
+            :param measures: list of measures for general risk model data request
+            :param start_date: start date for data request
+            :param end_date: end date for data request
+            :param assets: DataAssetsRequest object with identifier and list of assets to retrieve for request
+            :param limit_factors: limit factors included in factorData and covariance matrix to only include factors
+                which the input universe has non-zero exposure to
+            :return: factor portfolios data """
         return GsFactorRiskModelApi.get_risk_model_data(
             model_id=self.id,
             start_date=start_date,
@@ -542,35 +582,51 @@ class FactorRiskModel(RiskModel):
             limit_factors=limit_factors
         )
 
-    def upload_data(self, data: Union[RiskModelData, Dict]) -> Union[str, List]:
-        """ Upload risk model data to existing risk model """
-        data = data.to_json if type(data) == RiskModel else data
+    def upload_data(self, data: Union[RiskModelData, Dict]):
+        """ Upload risk model data to existing risk model in Marquee
+            :param data: complete risk model data for uploading on given date
+                includes: date, factorData, assetData, covarianceMatrix with optional inputs:
+                issuerSpecificCovariance and factorPortfolios
+
+            If upload universe is over 20000 assets, will batch and upload data in chunks of 20000 assets """
+
+        data = data.to_json() if type(data) == RiskModelData else data
         target_universe_size = len(data.get('assetData').get('universe'))
-        if target_universe_size > 15000:
-            return batch_and_upload_partial_data(self.id, data)
-        return GsFactorRiskModelApi.upload_risk_model_data(self.id, data)
+        if target_universe_size > 20000:
+            print('Batching uploads due to universe size')
+            batch_and_upload_partial_data(self.id, data)
+        else:
+            print(GsFactorRiskModelApi.upload_risk_model_data(self.id, data))
 
     def upload_partial_data(self, data: RiskModelData, target_universe_size: float = None):
-        """ Upload partial risk model data to existing risk model, if repeats in partial upload,
-            newer posted data will replace existing data on upload day """
-        GsFactorRiskModelApi.upload_risk_model_data(
+        """ Upload partial risk model data to existing risk model in Marquee
+            :param data: partial risk model data for uploading on given date
+            :param target_universe_size: the size of the complete universe on date
+
+            The models factorData and covarianceMatrix must be uploaded first on given date if repeats in partial
+                upload, newer posted data will replace existing data on upload day """
+        print(GsFactorRiskModelApi.upload_risk_model_data(
             self.id,
             data,
             partial_upload=True,
-            target_universe_size=target_universe_size
+            target_universe_size=target_universe_size)
         )
 
     def upload_asset_coverage_data(self, date: dt.date = None):
-        """Uploads to the coverage dataset for given risk model and date,
-         default date is last date from risk model calendar"""
+        """ Upload to the coverage dataset for given risk model and date
+            :param date: date to upload coverage data for, default date is last date from risk model calendar
+
+            Posting to the coverage dataset within in the last 5 days will enable the risk model to be seen in the
+                Marquee UI dropdown for users with "execute" capabilities """
         if not date:
             date = self.get_dates()[-1]
         update_time = dt.datetime.today().strftime("%Y-%m-%dT%H:%M:%SZ")
-        gsid_set = set(Dataset('RISK_MODEL_UNIVERSE').get_data(start=date, riskModel=self.id).gsid)
+        gsid_list = self.get_asset_universe(
+            date, assets=DataAssetsRequest('gsid', []), format=ReturnFormat.JSON).get(date)
         request_array = [{'date': date.strftime('%Y-%m-%d'),
                           'gsid': gsid,
                           'riskModel': self.id,
-                          'updateTime': update_time} for gsid in gsid_set]
+                          'updateTime': update_time} for gsid in set(gsid_list)]
         list_of_requests = list(divide_request(request_array, 1000))
         for request_set in list_of_requests:
-            GsDataApi.upload_data('RISK_MODEL_ASSET_COVERAGE', request_set)
+            print(GsDataApi.upload_data('RISK_MODEL_ASSET_COVERAGE', request_set))
