@@ -95,15 +95,6 @@ class Format(EnumBase, Enum):
         return self.value
 
 
-class AssetUniverseIdentifier(EnumBase, Enum):
-    """Identifier by which risk model is queried"""
-
-    gsid = 'gsid'
-
-    def __repr__(self):
-        return self.value
-
-
 class AssetData(Base):
 
     @camel_case_translate
@@ -358,22 +349,22 @@ class DataAssetsRequest(Base):
     @camel_case_translate
     def __init__(
             self,
-            identifier: Union[AssetUniverseIdentifier, str],
+            identifier: Union[UniverseIdentifier, str],
             universe: List[str]
     ):
         super().__init__()
-        self.identifier = get_enum_value(AssetUniverseIdentifier, identifier)
+        self.identifier = get_enum_value(UniverseIdentifier, identifier)
         self.universe = universe
 
     @property
-    def identifier(self) -> Union[AssetUniverseIdentifier, str]:
+    def identifier(self) -> Union[UniverseIdentifier, str]:
         """The identifier by which the risk model is queried"""
         return self.__identifier
 
     @identifier.setter
-    def identifier(self, value: Union[AssetUniverseIdentifier, str]):
+    def identifier(self, value: Union[UniverseIdentifier, str]):
         self._property_changed('identifier')
-        self.__identifier = get_enum_value(AssetUniverseIdentifier, value)
+        self.__identifier = get_enum_value(UniverseIdentifier, value)
 
     @property
     def universe(self) -> List[str]:
@@ -392,14 +383,14 @@ class RiskModelData(Base):
     def __init__(
             self,
             date: datetime.date,
-            asset_data: AssetData,
-            factor_data: List[FactorData],
-            covariance_matrix: List,
+            asset_data: AssetData = None,
+            factor_data: List[FactorData] = None,
+            covariance_matrix: List = None,
             issuer_specific_covariance: CovarianceData = None,
             factor_portfolios: FactorPortfolioData = None
     ):
         super().__init__()
-        self.date = date
+        self.date = date.strftime('%Y-%m-%d')
         self.asset_data = asset_data
         self.factor_data = factor_data
         self.covariance_matrix = covariance_matrix
