@@ -22,8 +22,8 @@ from gs_quant.api.gs.data import QueryType
 from gs_quant.data.core import DataContext
 from gs_quant.entities.entity import EntityType
 from gs_quant.markets.factor import Factor
-from gs_quant.models.risk_model import FactorRiskModel
 from gs_quant.markets.securities import Asset
+from gs_quant.models.risk_model import FactorRiskModel, ReturnFormat
 from gs_quant.target.common import AssetClass, AssetType
 from gs_quant.target.risk_models import Measure, DataAssetsRequest, UniverseIdentifier
 from gs_quant.timeseries import plot_measure_entity, plot_measure
@@ -44,8 +44,8 @@ def factor_zscore(asset: Asset, risk_model_id: str, factor_name: str, *,
     :param request_id: service request id, if any
     :return: Time-series of asset factor exposure across available risk model dates
     """
-    risk_model = FactorRiskModel(risk_model_id)
-    factor = Factor(risk_model_id, factor_name)
+    risk_model = FactorRiskModel.get(risk_model_id)
+    factor = Factor.get(risk_model_id, factor_name)
     gsid = asset.get_identifier('GSID')
 
     # Query risk model data
@@ -67,8 +67,8 @@ def factor_zscore(asset: Asset, risk_model_id: str, factor_name: str, *,
 
 
 @plot_measure_entity(EntityType.RISK_MODEL, [QueryType.FACTOR_RETURN])
-def covariance(risk_model_id: str, factor_name_1: str, factor_name_2: str, *, source: str = None,
-               real_time: bool = False, request_id: Optional[str] = None) -> pd.Series:
+def factor_covariance(risk_model_id: str, factor_name_1: str, factor_name_2: str, *, source: str = None,
+                      real_time: bool = False, request_id: Optional[str] = None) -> pd.Series:
     """
     Covariance time-series between two factors in a risk model
 
@@ -81,9 +81,12 @@ def covariance(risk_model_id: str, factor_name_1: str, factor_name_2: str, *, so
     :return: Time-series of covariances between the two factors across available risk model dates
     """
 
-    factor_1 = Factor(risk_model_id, factor_name_1)
-    factor_2 = Factor(risk_model_id, factor_name_2)
-    covariance_curve = factor_1.covariance(factor_2, DataContext.current.start_date, DataContext.current.end_date)
+    factor_1 = Factor.get(risk_model_id, factor_name_1)
+    factor_2 = Factor.get(risk_model_id, factor_name_2)
+    covariance_curve = factor_1.covariance(factor_2,
+                                           DataContext.current.start_date,
+                                           DataContext.current.end_date,
+                                           ReturnFormat.JSON)
     return __format_plot_measure_results(covariance_curve, QueryType.COVARIANCE)
 
 
@@ -100,8 +103,10 @@ def factor_volatility(risk_model_id: str, factor_name: str, *, source: str = Non
     :param request_id: server request id
     :return: Time-series of a factor's volatility across available risk model dates
     """
-    factor = Factor(risk_model_id, factor_name)
-    volatility = factor.volatility(DataContext.current.start_date, DataContext.current.end_date)
+    factor = Factor.get(risk_model_id, factor_name)
+    volatility = factor.volatility(DataContext.current.start_date,
+                                   DataContext.current.end_date,
+                                   ReturnFormat.JSON)
     return __format_plot_measure_results(volatility, QueryType.VOLATILITY, multiplier=100)
 
 
@@ -119,9 +124,12 @@ def factor_correlation(risk_model_id: str, factor_name_1: str, factor_name_2: st
     :param request_id: server request id
     :return: Time-series of correlations between the two factors across available risk model dates
     """
-    factor_1 = Factor(risk_model_id, factor_name_1)
-    factor_2 = Factor(risk_model_id, factor_name_2)
-    correlation = factor_1.correlation(factor_2, DataContext.current.start_date, DataContext.current.end_date)
+    factor_1 = Factor.get(risk_model_id, factor_name_1)
+    factor_2 = Factor.get(risk_model_id, factor_name_2)
+    correlation = factor_1.correlation(factor_2,
+                                       DataContext.current.start_date,
+                                       DataContext.current.end_date,
+                                       ReturnFormat.JSON)
     return __format_plot_measure_results(correlation, QueryType.CORRELATION)
 
 
